v1beta1

package
v0.0.8 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jul 24, 2020 License: UPL-1.0 Imports: 8 Imported by: 0

Documentation

Overview

This package has the automatically generated typed clients.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type CohClusterExpansion

type CohClusterExpansion interface{}

type CohClusterInterface

type CohClusterInterface interface {
	Create(ctx context.Context, cohCluster *v1beta1.CohCluster, opts v1.CreateOptions) (*v1beta1.CohCluster, error)
	Update(ctx context.Context, cohCluster *v1beta1.CohCluster, opts v1.UpdateOptions) (*v1beta1.CohCluster, error)
	Delete(ctx context.Context, name string, opts v1.DeleteOptions) error
	DeleteCollection(ctx context.Context, opts v1.DeleteOptions, listOpts v1.ListOptions) error
	Get(ctx context.Context, name string, opts v1.GetOptions) (*v1beta1.CohCluster, error)
	List(ctx context.Context, opts v1.ListOptions) (*v1beta1.CohClusterList, error)
	Watch(ctx context.Context, opts v1.ListOptions) (watch.Interface, error)
	Patch(ctx context.Context, name string, pt types.PatchType, data []byte, opts v1.PatchOptions, subresources ...string) (result *v1beta1.CohCluster, err error)
	CohClusterExpansion
}

CohClusterInterface has methods to work with CohCluster resources.

type CohClustersGetter

type CohClustersGetter interface {
	CohClusters(namespace string) CohClusterInterface
}

CohClustersGetter has a method to return a CohClusterInterface. A group's client should implement this interface.

type VerrazzanoV1beta1Client

type VerrazzanoV1beta1Client struct {
	// contains filtered or unexported fields
}

VerrazzanoV1beta1Client is used to interact with features provided by the verrazzano.io group.

func New

New creates a new VerrazzanoV1beta1Client for the given RESTClient.

func NewForConfig

func NewForConfig(c *rest.Config) (*VerrazzanoV1beta1Client, error)

NewForConfig creates a new VerrazzanoV1beta1Client for the given config.

func NewForConfigOrDie

func NewForConfigOrDie(c *rest.Config) *VerrazzanoV1beta1Client

NewForConfigOrDie creates a new VerrazzanoV1beta1Client for the given config and panics if there is an error in the config.

func (*VerrazzanoV1beta1Client) CohClusters

func (c *VerrazzanoV1beta1Client) CohClusters(namespace string) CohClusterInterface

func (*VerrazzanoV1beta1Client) RESTClient

func (c *VerrazzanoV1beta1Client) RESTClient() rest.Interface

RESTClient returns a RESTClient that is used to communicate with API server by this client implementation.

type VerrazzanoV1beta1Interface

type VerrazzanoV1beta1Interface interface {
	RESTClient() rest.Interface
	CohClustersGetter
}

Directories

Path Synopsis
Package fake has the automatically generated clients.
Package fake has the automatically generated clients.

Jump to