Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type CohClusterLister ¶
type CohClusterLister interface {
// List lists all CohClusters in the indexer.
List(selector labels.Selector) (ret []*v1beta1.CohCluster, err error)
// CohClusters returns an object that can list and get CohClusters.
CohClusters(namespace string) CohClusterNamespaceLister
CohClusterListerExpansion
}
CohClusterLister helps list CohClusters.
func NewCohClusterLister ¶
func NewCohClusterLister(indexer cache.Indexer) CohClusterLister
NewCohClusterLister returns a new CohClusterLister.
type CohClusterListerExpansion ¶
type CohClusterListerExpansion interface{}
CohClusterListerExpansion allows custom methods to be added to CohClusterLister.
type CohClusterNamespaceLister ¶
type CohClusterNamespaceLister interface {
// List lists all CohClusters in the indexer for a given namespace.
List(selector labels.Selector) (ret []*v1beta1.CohCluster, err error)
// Get retrieves the CohCluster from the indexer for a given namespace and name.
Get(name string) (*v1beta1.CohCluster, error)
CohClusterNamespaceListerExpansion
}
CohClusterNamespaceLister helps list and get CohClusters.
type CohClusterNamespaceListerExpansion ¶
type CohClusterNamespaceListerExpansion interface{}
CohClusterNamespaceListerExpansion allows custom methods to be added to CohClusterNamespaceLister.
Click to show internal directories.
Click to hide internal directories.